@@ -24,21 +24,14 @@ use PHPUnit\Event\Telemetry;
 final readonly class PreConditionErrored implements Event
 {
     private Telemetry\Info $telemetryInfo;
-
-    /**
-     * @var class-string
-     */
-    private string $testClassName;
+    private Code\TestMethod $test;
     private Code\ClassMethod $calledMethod;
     private Throwable $throwable;
 
-    /**
-     * @param class-string $testClassName
-     */
-    public function __construct(Telemetry\Info $telemetryInfo, string $testClassName, Code\ClassMethod $calledMethod, Throwable $throwable)
+    public function __construct(Telemetry\Info $telemetryInfo, Code\TestMethod $test, Code\ClassMethod $calledMethod, Throwable $throwable)
     {
         $this->telemetryInfo = $telemetryInfo;
-        $this->testClassName = $testClassName;
+        $this->test          = $test;
         $this->calledMethod  = $calledMethod;
         $this->throwable     = $throwable;
     }
@@ -48,12 +41,19 @@ final readonly class PreConditionErrored implements Event
         return $this->telemetryInfo;
     }
 
+    public function test(): Code\TestMethod
+    {
+        return $this->test;
+    }
+
     /**
      * @return class-string
+     *
+     * @deprecated https://github.com/sebastianbergmann/phpunit/issues/6140
      */
     public function testClassName(): string
     {
-        return $this->testClassName;
+        return $this->test->className();
     }
 
     public function calledMethod(): Code\ClassMethod
@@ -66,11 +66,14 @@ final readonly class PreConditionErrored implements Event
         return $this->throwable;
     }
 
+    /**
+     * @return non-empty-string
+     */
     public function asString(): string
     {
         $message = $this->throwable->message();
 
-        if (!empty($message)) {
+        if ($message !== '') {
             $message = PHP_EOL . $message;
         }
 
