@@ -9,13 +9,21 @@
  */
 namespace PHPUnit\Framework\Constraint;
 
+use function assert;
 use function gettype;
+use function is_int;
+use function is_object;
 use function sprintf;
+use function str_replace;
+use function strpos;
 use function strtolower;
+use function substr;
 use Countable;
+use PHPUnit\Framework\Assert;
 use PHPUnit\Framework\ExpectationFailedException;
 use PHPUnit\Framework\SelfDescribing;
 use PHPUnit\Util\Exporter;
+use ReflectionObject;
 use SebastianBergmann\Comparator\ComparisonFailure;
 
 /**
@@ -23,6 +31,20 @@ use SebastianBergmann\Comparator\ComparisonFailure;
  */
 abstract class Constraint implements Countable, SelfDescribing
 {
+    /**
+     * @template A
+     *
+     * @param A $actual
+     *
+     * @return A
+     */
+    final public function __invoke(mixed $actual): mixed
+    {
+        Assert::assertThat($actual, $this);
+
+        return $actual;
+    }
+
     /**
      * Evaluates the constraint for parameter $other.
      *
@@ -87,11 +109,11 @@ abstract class Constraint implements Countable, SelfDescribing
 
         $additionalFailureDescription = $this->additionalFailureDescription($other);
 
-        if ($additionalFailureDescription) {
+        if ($additionalFailureDescription !== '') {
             $failureDescription .= "\n" . $additionalFailureDescription;
         }
 
-        if (!empty($description)) {
+        if ($description !== '') {
             $failureDescription = $description . "\n" . $failureDescription;
         }
 
@@ -236,6 +258,24 @@ abstract class Constraint implements Countable, SelfDescribing
      */
     protected function valueToTypeStringFragment(mixed $value): string
     {
+        if (is_object($value)) {
+            $reflector = new ReflectionObject($value);
+
+            if ($reflector->isAnonymous()) {
+                $name = str_replace('class@anonymous', '', $reflector->getName());
+
+                $length = strpos($name, '$');
+
+                assert(is_int($length));
+
+                $name = substr($name, 0, $length);
+
+                return 'an instance of anonymous class created at ' . $name . ' ';
+            }
+
+            return 'an instance of class ' . $reflector->getName() . ' ';
+        }
+
         $type = strtolower(gettype($value));
 
         if ($type === 'double') {
@@ -247,7 +287,7 @@ abstract class Constraint implements Countable, SelfDescribing
         }
 
         return match ($type) {
-            'array', 'integer', 'object' => 'an ' . $type . ' ',
+            'array', 'integer' => 'an ' . $type . ' ',
             'boolean', 'closed resource', 'float', 'resource', 'string' => 'a ' . $type . ' ',
             'null'  => 'null ',
             default => 'a value of ' . $type . ' ',
