@@ -9,25 +9,25 @@
  */
 namespace PHPUnit\Framework\MockObject;
 
+use function get_debug_type;
 use function sprintf;
 
 /**
+ * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
+ *
  * @internal This class is not covered by the backward compatibility promise for PHPUnit
  */
 final class IncompatibleReturnValueException extends \PHPUnit\Framework\Exception implements Exception
 {
-    /**
-     * @param mixed $value
-     */
-    public function __construct(ConfigurableMethod $method, $value)
+    public function __construct(ConfigurableMethod $method, mixed $value)
     {
         parent::__construct(
             sprintf(
-                'Method %s may not return value of type %s, its return declaration is "%s"',
-                $method->getName(),
-                is_object($value) ? get_class($value) : gettype($value),
-                $method->getReturnTypeDeclaration()
-            )
+                'Method %s may not return value of type %s, its declared return type is "%s"',
+                $method->name(),
+                get_debug_type($value),
+                $method->returnTypeDeclaration(),
+            ),
         );
     }
 }
