@@ -109,7 +109,7 @@ abstract class NameFilterIterator extends RecursiveFilterIterator
             //  * testDetermineJsonError@JSON.*
             elseif (preg_match('/^(.*?)@(.+)$/', $filter, $matches)) {
                 $filter = sprintf(
-                    '%s.*with data set "@%s"$',
+                    '%s.*with data set "%s"$',
                     $matches[1],
                     $matches[2],
                 );
