@@ -371,6 +371,7 @@ final readonly class Merger
         $coverageTextShowUncoveredFiles = false;
         $coverageTextShowOnlySummary    = false;
         $coverageXml                    = null;
+        $coverageXmlIncludeSource       = true;
         $coverageFromXmlConfiguration   = true;
 
         if ($cliConfiguration->hasNoCoverage() && $cliConfiguration->noCoverage()) {
@@ -462,6 +463,12 @@ final readonly class Merger
             $coverageXml = $xmlConfiguration->codeCoverage()->xml()->target()->path();
         }
 
+        if ($cliConfiguration->hasExcludeSourceFromXmlCoverage()) {
+            $coverageXmlIncludeSource = !$cliConfiguration->excludeSourceFromXmlCoverage();
+        } elseif ($coverageFromXmlConfiguration && $xmlConfiguration->codeCoverage()->hasXml()) {
+            $coverageXmlIncludeSource = $xmlConfiguration->codeCoverage()->xml()->includeSource();
+        }
+
         if ($cliConfiguration->hasBackupGlobals()) {
             $backupGlobals = $cliConfiguration->backupGlobals();
         } else {
@@ -750,15 +757,25 @@ final readonly class Merger
             $excludeFilter = $cliConfiguration->excludeFilter();
         }
 
+        $ignoreTestSelectionInXmlConfiguration = false;
+
+        if ($cliConfiguration->hasAll()) {
+            $ignoreTestSelectionInXmlConfiguration = true;
+        }
+
+        $groups = [];
+
         if ($cliConfiguration->hasGroups()) {
             $groups = $cliConfiguration->groups();
-        } else {
+        } elseif (!$ignoreTestSelectionInXmlConfiguration) {
             $groups = $xmlConfiguration->groups()->include()->asArrayOfStrings();
         }
 
+        $excludeGroups = [];
+
         if ($cliConfiguration->hasExcludeGroups()) {
             $excludeGroups = $cliConfiguration->excludeGroups();
-        } else {
+        } elseif (!$ignoreTestSelectionInXmlConfiguration) {
             $excludeGroups = $xmlConfiguration->groups()->exclude()->asArrayOfStrings();
         }
 
@@ -865,31 +882,31 @@ final readonly class Merger
             $displayDetailsOnAllIssues = true;
         }
 
-        if ($failOnDeprecation) {
+        if ($failOnDeprecation && !$doNotFailOnDeprecation) {
             $displayDetailsOnTestsThatTriggerDeprecations = true;
         }
 
-        if ($failOnPhpunitDeprecation) {
+        if ($failOnPhpunitDeprecation && !$doNotFailOnPhpunitDeprecation) {
             $displayDetailsOnPhpunitDeprecations = true;
         }
 
-        if ($failOnPhpunitNotice) {
+        if ($failOnPhpunitNotice && !$doNotFailOnPhpunitNotice) {
             $displayDetailsOnPhpunitNotices = true;
         }
 
-        if ($failOnNotice) {
+        if ($failOnNotice && !$doNotFailOnNotice) {
             $displayDetailsOnTestsThatTriggerNotices = true;
         }
 
-        if ($failOnWarning) {
+        if ($failOnWarning && !$doNotFailOnWarning) {
             $displayDetailsOnTestsThatTriggerWarnings = true;
         }
 
-        if ($failOnIncomplete) {
+        if ($failOnIncomplete && !$doNotFailOnIncomplete) {
             $displayDetailsOnIncompleteTests = true;
         }
 
-        if ($failOnSkipped) {
+        if ($failOnSkipped && !$doNotFailOnSkipped) {
             $displayDetailsOnSkippedTests = true;
         }
 
@@ -897,6 +914,7 @@ final readonly class Merger
             $cliConfiguration->arguments(),
             $configurationFile,
             $bootstrap,
+            $xmlConfiguration->phpunit()->bootstrapForTestSuite(),
             $cacheResult,
             $cacheDirectory,
             $coverageCacheDirectory,
@@ -941,6 +959,7 @@ final readonly class Merger
             $coverageTextShowUncoveredFiles,
             $coverageTextShowOnlySummary,
             $coverageXml,
+            $coverageXmlIncludeSource,
             $pathCoverage,
             $xmlConfiguration->codeCoverage()->ignoreDeprecatedCodeUnits(),
             $disableCodeCoverageIgnore,
@@ -1034,6 +1053,7 @@ final readonly class Merger
             $includeTestSuite,
             $excludeTestSuite,
             $xmlConfiguration->phpunit()->hasDefaultTestSuite() ? $xmlConfiguration->phpunit()->defaultTestSuite() : null,
+            $ignoreTestSelectionInXmlConfiguration,
             $testSuffixes,
             new Php(
                 DirectoryCollection::fromArray($includePaths),
