@@ -170,6 +170,7 @@ final class Help
             ],
 
             'Selection' => [
+                ['arg' => '--all', 'desc' => 'Ignore test selection from XML configuration file'],
                 ['arg' => '--list-suites', 'desc' => 'List available test suites'],
                 ['arg' => '--testsuite <name>', 'desc' => 'Only run tests from the specified test suite(s)'],
                 ['arg' => '--exclude-testsuite <name>', 'desc' => 'Exclude tests from the specified test suite(s)'],
@@ -301,6 +302,7 @@ final class Help
                 ['arg' => '--only-summary-for-coverage-text', 'desc' => 'Option for code coverage report in text format: only show summary'],
                 ['arg' => '--show-uncovered-for-coverage-text', 'desc' => 'Option for code coverage report in text format: show uncovered files'],
                 ['arg' => '--coverage-xml <dir>', 'desc' => 'Write code coverage report in XML format to directory'],
+                ['arg' => '--exclude-source-from-xml-coverage', 'desc' => 'Exclude <source> element from code coverage report in XML format'],
                 ['arg' => '--warm-coverage-cache', 'desc' => 'Warm static analysis cache'],
                 ['arg' => '--coverage-filter <dir>', 'desc' => 'Include <dir> in code coverage reporting'],
                 ['arg' => '--path-coverage', 'desc' => 'Report path coverage in addition to line coverage'],
