@@ -9,21 +9,18 @@
  */
 namespace PHPUnit\TextUI\Output\Default;
 
-use PHPUnit\Event\EventFacadeIsSealedException;
 use PHPUnit\Event\Facade;
 use PHPUnit\Event\Test\PrintedUnexpectedOutput;
 use PHPUnit\Event\Test\PrintedUnexpectedOutputSubscriber;
-use PHPUnit\Event\UnknownSubscriberTypeException;
 use PHPUnit\TextUI\Output\Printer;
 
+/**
+ * @no-named-arguments Parameter names are not covered by the backward compatibility promise for PHPUnit
+ */
 final readonly class UnexpectedOutputPrinter implements PrintedUnexpectedOutputSubscriber
 {
     private Printer $printer;
 
-    /**
-     * @throws EventFacadeIsSealedException
-     * @throws UnknownSubscriberTypeException
-     */
     public function __construct(Printer $printer, Facade $facade)
     {
         $this->printer = $printer;
