@@ -24,6 +24,7 @@ use function is_array;
 use function is_resource;
 use function proc_close;
 use function proc_open;
+use function str_starts_with;
 use function stream_get_contents;
 use function sys_get_temp_dir;
 use function tempnam;
@@ -169,6 +170,16 @@ final readonly class DefaultJobRunner extends JobRunner
         $command     = [PHP_BINARY];
         $phpSettings = $job->phpSettings();
 
+        $xdebugModeConfiguredExplicitly = false;
+
+        foreach ($phpSettings as $phpSetting) {
+            if (str_starts_with($phpSetting, 'xdebug.mode')) {
+                $xdebugModeConfiguredExplicitly = true;
+
+                break;
+            }
+        }
+
         if ($runtime->hasPCOV()) {
             $pcovSettings = ini_get_all('pcov');
 
@@ -195,6 +206,7 @@ final readonly class DefaultJobRunner extends JobRunner
             );
 
             if (
+                !$xdebugModeConfiguredExplicitly &&
                 !CodeCoverage::instance()->isActive() &&
                 xdebug_is_debugger_active() === false &&
                 !$job->requiresXdebug()
