@@ -9,6 +9,7 @@
  */
 namespace PHPUnit\TestFixture;
 
+use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\TestCase;
 
 trait T3194
@@ -29,9 +30,7 @@ final class C3194
     }
 }
 
-/**
- * @covers \PHPUnit\TestFixture\C3194
- */
+#[CoversClass(C3194::class)]
 final class Test3194 extends TestCase
 {
     public function testOne(): void
