@@ -11,7 +11,7 @@ namespace PHPUnit\TestFixture;
 
 use PHPUnit\Framework\TestCase;
 
-class IncompleteTest extends TestCase
+final class IncompleteTest extends TestCase
 {
     public function testIncomplete(): void
     {
