@@ -10,21 +10,13 @@
 namespace PHPUnit\TestFixture;
 
 use FooBarHandler;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\TestCase;
 
 final class RouterTest extends TestCase
 {
-    /**
-     * @dataProvider routesProvider
-     *
-     * @testdox      Routes $url to $handler
-     */
-    public function testRoutesRequest(string $url, string $handler): void
-    {
-        $this->assertTrue(true);
-    }
-
-    public function routesProvider()
+    public static function routesProvider(): array
     {
         return [
             '/foo/bar' => [
@@ -34,4 +26,11 @@ final class RouterTest extends TestCase
             ],
         ];
     }
+
+    #[DataProvider('routesProvider')]
+    #[TestDox('Routes $url to $handler')]
+    public function testRoutesRequest(string $url, string $handler): void
+    {
+        $this->assertTrue(true);
+    }
 }
