@@ -11,13 +11,11 @@ namespace PHPUnit\TestFixture\TestBuilder;
 
 use PHPUnit\Framework\Attributes\BackupGlobals;
 use PHPUnit\Framework\Attributes\BackupStaticProperties;
-use PHPUnit\Framework\Attributes\RunClassInSeparateProcess;
 use PHPUnit\Framework\Attributes\RunTestsInSeparateProcesses;
 use PHPUnit\Framework\TestCase;
 
 #[BackupGlobals(true)]
 #[BackupStaticProperties(true)]
-#[RunClassInSeparateProcess]
 #[RunTestsInSeparateProcesses]
 final class TestWithClassLevelIsolationAttributes extends TestCase
 {
