@@ -15,7 +15,11 @@ final class MockTest extends TestCase
 {
     public function testSuccess(): void
     {
-        $this->createMock(Example::class);
+        $mock = $this->createMock(Example::class);
+
+        $mock
+            ->expects($this->never())
+            ->method('doSomething');
 
         $this->assertTrue(true);
     }
