@@ -7,7 +7,17 @@
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-class Under_Score_Issue5020Test extends PHPUnit\Framework\TestCase
+use PHPUnit\Framework\TestCase;
+
+/*
+ * This file is part of PHPUnit.
+ *
+ * (c) Sebastian Bergmann <sebastian@phpunit.de>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
+class Under_Score_Issue5020Test extends TestCase
 {
     public function testTrue(): void
     {
