@@ -13,7 +13,7 @@ use PHPUnit\Framework\TestCase;
 
 final class MyClassTest extends TestCase
 {
-    public const VALUE = true;
+    public const bool VALUE = true;
 
     public function test(): void
     {
