@@ -12,8 +12,8 @@ namespace PHPUnit\Framework\MockObject;
 use function md5;
 use function mt_rand;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\CoversMethod;
 use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnorePhpunitDeprecations;
 use PHPUnit\Framework\Attributes\Medium;
 use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\MockObject\Generator\DuplicateMethodException;
@@ -26,6 +26,7 @@ use PHPUnit\TestFixture\MockObject\ExtendableClassWithConstructorArguments;
 use PHPUnit\TestFixture\MockObject\InterfaceWithReturnTypeDeclaration;
 
 #[CoversClass(MockBuilder::class)]
+#[CoversMethod(TestCase::class, 'getMockBuilder')]
 #[CoversClass(DuplicateMethodException::class)]
 #[CoversClass(InvalidMethodNameException::class)]
 #[CoversClass(NameAlreadyInUseException::class)]
@@ -83,7 +84,6 @@ final class MockBuilderTest extends TestCase
         $this->assertTrue($double->doSomething());
     }
 
-    #[IgnorePhpunitDeprecations]
     public function testDefaultBehaviourCanBeConfiguredExplicitly(): void
     {
         $double = $this->getMockBuilder(ExtendableClass::class)
