@@ -13,10 +13,8 @@ use function call_user_func_array;
 use Exception;
 use PHPUnit\Framework\Attributes\DoesNotPerformAssertions;
 use PHPUnit\Framework\Attributes\Group;
-use PHPUnit\Framework\Attributes\IgnorePhpunitDeprecations;
 use PHPUnit\Framework\Attributes\Medium;
 use PHPUnit\Framework\Attributes\RequiresMethod;
-use PHPUnit\Framework\Attributes\RequiresPhp;
 use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\ExpectationFailedException;
 use PHPUnit\Framework\MockObject\Runtime\PropertyHook;
@@ -26,12 +24,10 @@ use PHPUnit\TestFixture\MockObject\ExtendableClassWithCloneMethod;
 use PHPUnit\TestFixture\MockObject\ExtendableClassWithPropertyWithSetHook;
 use PHPUnit\TestFixture\MockObject\ExtendableReadonlyClassWithCloneMethod;
 use PHPUnit\TestFixture\MockObject\InterfaceWithImplicitProtocol;
-use PHPUnit\TestFixture\MockObject\InterfaceWithMethodThatExpectsObject;
 use PHPUnit\TestFixture\MockObject\InterfaceWithPropertyWithSetHook;
 use PHPUnit\TestFixture\MockObject\InterfaceWithReturnTypeDeclaration;
 use PHPUnit\TestFixture\MockObject\MethodWIthVariadicVariables;
 use ReflectionProperty;
-use stdClass;
 
 #[Group('test-doubles')]
 #[Group('test-doubles/mock-object')]
@@ -430,22 +426,12 @@ EOT,
         $this->fail();
     }
 
-    #[IgnorePhpunitDeprecations]
-    public function testExpectationsCanBeConfiguredOnTestStubs(): void
-    {
-        $double = $this->createStub(AnInterface::class);
-
-        $double->expects($this->never())->method('doSomething');
-
-        $this->assertTrue(true);
-    }
-
     public function testWillReturnCallbackWithVariadicVariables(): void
     {
         $double = $this->createMock(MethodWIthVariadicVariables::class);
         $double->expects($this->once())->method('testVariadic')
             ->withAnyParameters()
-            ->willReturnCallback(static fn ($string, ...$arguments) => [$string, ...$arguments]);
+            ->willReturnCallback(static fn (string $string, string ...$arguments) => [$string, ...$arguments]);
 
         $testData = ['foo', 'bar', 'biz' => 'kuz'];
         $actual   = $double->testVariadic(...$testData);
@@ -512,20 +498,6 @@ EOT,
         $double->doSomething();
     }
 
-    #[IgnorePhpunitDeprecations]
-    public function testCloningOfObjectsPassedAsArgumentCanBeEnabled(): void
-    {
-        $object = new stdClass;
-
-        $double = $this->getMockBuilder(InterfaceWithMethodThatExpectsObject::class)
-            ->enableArgumentCloning()
-            ->getMock();
-
-        $double->method('doSomething')->willReturnArgument(0);
-
-        $this->assertNotSame($object, $double->doSomething($object));
-    }
-
     #[TestDox('Original __clone() method can optionally be called when test double object is cloned')]
     public function testOriginalCloneMethodCanOptionallyBeCalledWhenTestDoubleObjectIsCloned(): void
     {
@@ -538,7 +510,6 @@ EOT,
     }
 
     #[TestDox('Original __clone() method can optionally be called when test double object is cloned (readonly class)')]
-    #[RequiresPhp('^8.3')]
     public function testOriginalCloneMethodCanOptionallyBeCalledWhenTestDoubleObjectOfReadonlyClassIsCloned(): void
     {
         $double = $this->getMockBuilder(ExtendableReadonlyClassWithCloneMethod::class)->enableOriginalClone()->getMock();
