@@ -29,6 +29,26 @@ final class BuilderTest extends TestCase
         $this->assertSame(['argument'], $configuration->arguments());
     }
 
+    #[TestDox('--all')]
+    public function testAll(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--all']);
+
+        $this->assertTrue($configuration->hasAll());
+        $this->assertTrue($configuration->all());
+    }
+
+    public function testAllMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasAll());
+
+        $this->expectException(Exception::class);
+
+        $configuration->all();
+    }
+
     #[TestDox('--colors')]
     public function testColorsImplicitAuto(): void
     {
@@ -427,6 +447,26 @@ final class BuilderTest extends TestCase
         $configuration->coverageXml();
     }
 
+    #[TestDox('--exclude-source-from-xml-coverage=')]
+    public function testExcludeSourceFromXmlCoverage(): void
+    {
+        $configuration = (new Builder)->fromParameters(['--exclude-source-from-xml-coverage']);
+
+        $this->assertTrue($configuration->hasExcludeSourceFromXmlCoverage());
+        $this->assertTrue($configuration->excludeSourceFromXmlCoverage());
+    }
+
+    public function testExcludeSourceFromXmlCoverageMayNotBeConfigured(): void
+    {
+        $configuration = (new Builder)->fromParameters([]);
+
+        $this->assertFalse($configuration->hasExcludeSourceFromXmlCoverage());
+
+        $this->expectException(Exception::class);
+
+        $configuration->excludeSourceFromXmlCoverage();
+    }
+
     #[TestDox('--path-coverage')]
     public function testPathCoverage(): void
     {
